from setuptools import setup

setup(name='chushajo',
      version='0.1',
      description='Parking API',
      url='https://github.com/kimi1989/chushajo.git',
      author='Kimi Jin',
      author_email='jinyinzhen@gmail.com',
      license='MIT',
      packages=['chushajo'],
      zip_safe=False)